kedro.framework — Kedro 0.17.6 documentation

# kedro.framework

Description

`kedro.framework` provides Kedro’s framework components

Modules

`kedro.framework.cli` | `kedro.framework.cli` implements commands available from Kedro’s CLI.
`kedro.framework.context` | `kedro.framework.context` provides functionality for loading Kedro project context.
`kedro.framework.hooks` | `kedro.framework.hooks` provides primitives to use hooks to extend KedroContext’s behaviour
`kedro.framework.project` | `kedro.framework.project` module provides utitlity to configure a Kedro project and access its settings.
`kedro.framework.session` | `kedro.framework.session` provides access to KedroSession responsible for project lifecycle.
`kedro.framework.startup` | This module provides metadata for a Kedro project.